#
# map3d5.rb

require "narray"
require "numru/advanceddcl"
include NumRu::AdvancedDCL
include NMath


nx = 21
ny = 21
xmin = -10
xmax = 10
ymin = -10
ymax = 10
vxmin = 0.2
vxmax = 0.8
vymin = 0.1
vymax = 0.5
zmin = 0.0
zmax = 20
vzmin = 0.0
vzmax = 0.6
xvp3 = -0.7
yvp3 = -0.7
zvp3 = 1.2
xfc3 = (vxmax-vxmin)/2
yfc3 = (vymax-vymin)/2
zfc3 = (vzmax-vzmin)/2
dx1 = 1
dx2 = 5
d1 = 1
d2 = 4
dz1 = 1
dz2 = 5
kmax = 5
pmin = 0
pmax = 1
u = NArray.sfloat(nx, ny)
v = NArray.sfloat(nx, ny)
p = NArray.sfloat(nx, ny)

#-- data ---
for j in 0..ny-1
  for i in 0..nx-1
    x = xmin + (xmax-xmin)*i/(nx-1).to_f
    y = ymin + (ymax-ymin)*j/(ny-1).to_f
    u[i,j] =  x
    v[i,j] = -y
    p[i,j] = exp(-x**2/64 -y**2/25)
  end
end

#-- graph ---
Dev.open

Frame.new

#-- X-Y : x ----
Fig.window = [xmin, xmax, ymin, ymax]
Fig.viewport = [vxmin, vxmax, vymin, vymax]
Fig.transnum = 1

Fig.plane = [1, 2, vzmin]
Fig.eyepoint = [xvp3, yvp3, zvp3]
Fig.objpoint = [xfc3, yfc3, zfc3]

Axis::Lin.xaxdv('B', dx1, dx2)
Axis::Lin.xaxdv('T', dx1, dx2)
Axis::Lin.xsttl('B', 'X-axis', 0.0)

Axis::Lin.yaxdv('L', d1, d2)
Axis::Lin.yaxdv('R', d1, d2)
Axis::Lin.ysttl('L', 'Y-axis', 0.0)

Vector.rsizet = 0.014
Vector.draw(u, v)

#-- X-Y : ヌx ----
vzlev = vzmin + (vzmax-vzmin)*0.6
Fig.plane = [1, 2, vzlev]

dp = (pmax-pmin)/kmax.to_f
for k in 1..kmax
  tlev1 = (k-1)*dp
  tlev2 = tlev1 + dp
  ipat  = 600 + k - 1
  Tone.stlv(tlev1, tlev2, ipat)
end
Tone.draw(p)

Contour.lmsg = false
Contour.gclb(p, 0.1)
Contour.draw(p)
Frame.pvpr(1)

#-- X-Z  ---
Fig.new
Fig.window = [xmin, xmax, zmin, zmax]
Fig.viewport = [vxmin, vxmax, vzmin, vzmax]

Fig.plane = [1, 3, vymax]

Axis::Lin.yaxdv('L', dz1, dz2)
Axis::Lin.ysttl('L', 'Z-axis', 0.0)

Dev.close

